@@ -13,10 +13,11 @@ import time
 import asyncio
 from logging import Logger
 from urllib.parse import parse_qs
-from typing import List, Any, cast, Dict, Optional
+from typing import List, Any, cast, Dict, Optional, Union
 from playwright_helper.utils.log_utils import logger as _logger
 from playwright_helper.utils.type_utils import safe_parse_literal
-from playwright.async_api import Page, Locator, TimeoutError as PlaywrightTimeoutError, Request, Response
+from playwright.async_api import Page, Locator, TimeoutError as PlaywrightTimeoutError, Request, Response, \
+    Error as PlaywrightError
 
 
 class BasePo(object):
@@ -74,20 +75,20 @@ class BasePo(object):
                 return locator
             except PlaywrightTimeoutError as e:
                 raise PlaywrightTimeoutError(f"元素未在 {timeout} 秒内变为可见（严格模式）") from e
-            except Exception as e:
-                raise RuntimeError(f"检查元素时发生错误: {str(e)}") from e
-
-        # 快速模式：attached 超时设为 min(2秒, 总超时)
-        attached_timeout_ms = min(2000.0, timeout * 1000.0)  # 明确为 float，但实际传给 wait_for 会被转为 int
-        await locator.first.wait_for(state='attached', timeout=int(attached_timeout_ms))
+            except PlaywrightError as e:
+                raise PlaywrightError(f"检查元素时发生错误: {str(e)}") from e
 
         end_time = time.time() + timeout
+        last_exception: Optional[Exception] = None
         while time.time() < end_time:
-            if await locator.is_visible():
+            try:
+                await locator.first.wait_for(state='visible', timeout=300)
                 return locator
-            await asyncio.sleep(0.1)
+            except (PlaywrightTimeoutError, PlaywrightError) as e:
+                last_exception = e
+            await asyncio.sleep(0.05)
 
-        raise PlaywrightTimeoutError(f"元素未在 {timeout} 秒内变为可见（快速模式）")
+        raise PlaywrightTimeoutError(f"元素未在 {timeout} 秒内变为可见（快速模式）。最后异常: {last_exception}")
 
     async def get_locator(self, selector: str, timeout: float = 3.0, strict: bool = True) -> Locator:
         """
@@ -291,4 +292,32 @@ class BasePo(object):
         """
         if isinstance(text, str) is False:
             text = str(text)
-        await locator.type(text, delay=delay)
\ No newline at end of file
+        await locator.type(text, delay=delay)
+
+    async def page_screenshot(self, file_name: str = None, is_full_page: bool = False) -> Union[bytes, None]:
+        """
+        保存截图，默认截图整个可见页面（不是整个滚动区域）
+        :param file_name: 文件名，若没传递，这返回bytes
+        :param is_full_page: true---> 截图整个网页（包括滚动区域）
+        :return:
+        """
+        if is_full_page is True:
+            if file_name is None:
+                return await self.__page.screenshot()
+            await self.__page.screenshot(path=file_name, full_page=True)
+        else:
+            await self.__page.screenshot(path=file_name)
+
+    @staticmethod
+    async def locator_element_screenshot(locator: Locator, file_name: str = None) -> bytes:
+        """
+        元素截图
+        :param locator: Locator对象
+        :param file_name: 文件名，若没传递，这返回bytes
+        :return:
+        """
+        if file_name is None:
+            return await locator.screenshot(path=file_name)
+
+        else:
+            await locator.screenshot(path=file_name)
